@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.40';
+our $VERSION = '0.44';
 
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
 use Email::Address::List;
 use Encode qw( encode find_encoding );
 use MIME::Base64 qw( encode_base64 );
-use MooseX::Params::Validate qw( validated_list );
+use Params::ValidationCompiler qw( validation_for );
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -31,17 +31,17 @@ has value => (
 );
 
 {
-    my @spec = (
-        charset => { isa => NonEmptyStr, default => 'utf8' },
-        output  => { isa => Streamable,  coerce  => 1 },
+    my $validator = validation_for(
+        params => [
+            charset => { type => NonEmptyStr, default => 'utf8' },
+            output  => { type => Streamable },
+        ],
+        named_to_list => 1,
     );
 
     sub stream_to {
         my $self = shift;
-        my ( $charset, $output ) = validated_list(
-            \@_,
-            @spec
-        );
+        my ( $charset, $output ) = $validator->(@_);
 
         my $string = $self->name;
         $string .= ': ';
@@ -245,13 +245,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.40
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -262,8 +264,6 @@ version 0.40
 
 This class represents a single header, which consists of a name and value.
 
-=encoding utf-8
-
 =head1 API
 
 This class supports the following methods:
@@ -302,6 +302,13 @@ See the C<as_string()> method for documentation on the C<charset> parameter.
 
 This class does the C<Courriel::Role::Streams> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
